package com.osoboo.jira.metadata.ui.internal;

import com.atlassian.jira.project.Project;
import com.atlassian.jira.project.browse.BrowseContext;
import com.atlassian.jira.security.JiraAuthenticationContext;
import com.atlassian.jira.security.PermissionManager;
import com.atlassian.jira.security.roles.ProjectRole;
import com.atlassian.jira.security.roles.ProjectRoleManager;

public class MetadataHelper {

	/** the project admin permission key. */
	public static final int PROJECT_ADMIN = 23;

	public static boolean userIsNotInRole(ProjectRoleManager projectRoleManager, PermissionManager permissionManager,
			JiraAuthenticationContext authenticationContext, BrowseContext ctx, String toCheckRoles) {
		if (!toCheckRoles.isEmpty()) {
			for (String role : toCheckRoles.split(",")) {
				ProjectRole externalProjectRole = projectRoleManager.getProjectRole(role.trim());
				if (externalProjectRole != null
						&& projectRoleManager.isUserInProjectRole(authenticationContext.getLoggedInUser(), externalProjectRole,
								ctx.getProject())) {
					return userHasProjectAdminPermission(permissionManager, authenticationContext, ctx);
				}
			}
		}
		return true;
	}

	public static boolean userHasProjectAdminPermission(PermissionManager permissionManager,
			JiraAuthenticationContext authenticationContext, BrowseContext ctx) {
		return userHasProjectAdminPermission(permissionManager, authenticationContext, ctx.getProject());
	}

	public static boolean userHasProjectAdminPermission(PermissionManager permissionManager,
			JiraAuthenticationContext authenticationContext, Project project) {
		try {
			return permissionManager.hasPermission(PROJECT_ADMIN, project, authenticationContext.getLoggedInUser());
		} catch (NoSuchMethodError e) {
			return permissionManager.hasPermission(MetadataHelper.PROJECT_ADMIN, project, authenticationContext.getUser());
		}

	}

}
