package com.osoboo.jira.metadata.ui.internal;

import java.util.Map;

import com.atlassian.jira.plugin.versionpanel.BrowseVersionContext;
import com.atlassian.jira.plugin.versionpanel.VersionTabPanel;
import com.atlassian.jira.plugin.versionpanel.VersionTabPanelModuleDescriptor;
import com.atlassian.jira.security.JiraAuthenticationContext;
import com.atlassian.jira.security.PermissionManager;
import com.atlassian.jira.security.roles.ProjectRoleManager;
import com.atlassian.jira.util.JiraVelocityUtils;
import com.opensymphony.util.TextUtils;
import com.osoboo.jira.metadata.MetadataService;

public class VersionMetadataPanel implements VersionTabPanel {
	private VersionTabPanelModuleDescriptor descriptor;

	final protected JiraAuthenticationContext authenticationContext;
	private MetadataService metadataService;
	/** used to check the current users permission to edit the metadata. */
	private final PermissionManager permissionManager;
	private final ProjectRoleManager projectRoleManager;

	public VersionMetadataPanel(PermissionManager permissionManager, JiraAuthenticationContext jiraAuthenticationContext,
			MetadataService metadataService, ProjectRoleManager projectRoleManager) {
		this.authenticationContext = jiraAuthenticationContext;
		this.permissionManager = permissionManager;
		this.metadataService = metadataService;
		this.projectRoleManager = projectRoleManager;
	}

	@Override
	public void init(VersionTabPanelModuleDescriptor descriptor) {
		this.descriptor = descriptor;
	}

	@Override
	public String getHtml(BrowseVersionContext ctx) {
		final Map<String, Object> params = JiraVelocityUtils.getDefaultVelocityParams(authenticationContext);
		params.put("i18n", authenticationContext.getI18nHelper());
		params.put("project", ctx.getProject());
		params.put("version", ctx.getVersion());
		try {
			params.put("hasAdminPermission", permissionManager.hasPermission(MetadataHelper.PROJECT_ADMIN, ctx.getProject(),
					authenticationContext.getLoggedInUser()));
		} catch (NoSuchMethodError e) {
			// required for jira 4.2 support
			params.put("hasAdminPermission",
					permissionManager.hasPermission(MetadataHelper.PROJECT_ADMIN, ctx.getProject(), authenticationContext.getUser()));
		}
		params.put("metadataService", metadataService);
		// TODO aspall sollte noch anders gehen
		TextUtils textUtils = new TextUtils();
		params.put("textutils", textUtils);
		return descriptor.getHtml("view", params);
	}

	@Override
	public boolean showPanel(BrowseVersionContext ctx) {
		String hideRoles = metadataService.getMetadataValue(ctx.getVersion(), "jira.metadata.projectRole.hide.tab.version");
		return MetadataHelper.userIsNotInRole(projectRoleManager, permissionManager, authenticationContext, ctx, hideRoles);
	}

}
